/* mapview - map viewer for PalmOS
   Copyright (C) 2005  Edwin Steiner <edwin.steiner@gmx.net>

   This program is free software; you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
   the Free Software Foundation; either version 2 of the License, or
   (at your option) any later version.

   This program is distributed in the hope that it will be useful,
   but WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
   GNU General Public License for more details.

   You should have received a copy of the GNU General Public License
   along with this program; if not, write to the Free Software
   Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
*/

#ifndef _MAP_H_
#define _MAP_H_

#include "mapfile.h"

#define MapviewMapResourceType          'MVMp'
#define MapviewLayerResourceType        'MVLa'

#define MapviewMaprcID          1000
#define MapviewLayerrcID        2000

typedef struct mapview_map_t mapview_map_t;
typedef struct mapview_layer_t mapview_layer_t;

struct mapview_map_t {
        DmOpenRef               dbref;
        UInt32                  mapsizex;
        UInt32                  mapsizey;
        UInt16                  nlayers;
        UInt16                  density;
        mapview_layer_t **      layers;
        mapview_mapfile_t *     _mapfile;
};

struct mapview_layer_t {
        UInt16                      scale;
        UInt16                      tilesizex;
        UInt16                      tilesizey;
        UInt16                      tilesx;
        UInt16                      tilesy;
        UInt16                      tilebaseid;
        MemHandle                   _bitmaphandle;
        mapview_map_t *             _map;
        UInt32                      _tiledirofs;
        mapview_mapfile_tiledir_t * _tiledir;
};

#ifdef __cplusplus
extern "C" {
#endif

mapview_map_t *mapview_map_new(UInt16 cardno,LocalID dbid);
mapview_map_t *mapview_map_new_mapfile(mapview_mapfile_t *mapfile);
void mapview_map_free(mapview_map_t *map);

mapview_layer_t *mapview_layer_new(mapview_map_t *map,UInt32 id);
mapview_layer_t *mapview_layer_new_mapfile(mapview_map_t *map,mapview_mapfile_layerheader_t *layerheader);
void mapview_layer_free(mapview_layer_t *layer);

BitmapPtr mapview_layer_get_tile(mapview_layer_t *layer,Int32 tx,Int32 ty);
void mapview_layer_release_tile(mapview_layer_t *layer);

#ifdef __cplusplus
}
#endif

#endif

/* vim: et sts=8 sw=8 ai
 */
